==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.imagemgr/src/com/openexchange/office/imagemgr/DocumentImageHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.imagemgr;


public class DocumentImageHelper {

	// return the proper imageUrl for imageData, the imageData is inserted into the resourceManager,
	// the filter needs to take care to insert the resource into the document package then
	// 
    // a imageFolder sting is expected to have following format:: "word/media/"
    public static String getImageUrlFromImageData(ResourceManager resourceManager, String imageData, String imageFolder) {
        String imageUrl = null;
        if(imageData != null) {
            long uid = resourceManager.addBase64(imageData);
            if(uid!=0) {
                imageUrl = imageFolder + "uid" + Long.toHexString(uid);
                final String basePattern = "base64,";
                final String dataPattern = "data:image/";

                int pos = imageData.indexOf(basePattern);
                if (imageData.startsWith(dataPattern)) {
                    imageUrl += '.' + imageData.substring(dataPattern.length(), pos - 1);
                }
            }
        }
        return imageUrl;
    }
}

==> open-xchange-documents-backend_7.10.3.orig.tar.bz2: open-xchange-documents-backend-7.10.3/com.openexchange.office.imagemgr/src/com/openexchange/office/imagemgr/DocumentImageHelper.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.imagemgr;

import java.security.NoSuchAlgorithmException;
import org.apache.commons.lang3.StringUtils;

public class DocumentImageHelper {

	// return the proper imageUrl for imageData, the imageData is inserted into the resourceManager,
	// the filter needs to take care to insert the resource into the document package then
	//
    // a imageFolder sting is expected to have following format:: "word/media/"
    public static String getImageUrlFromImageData(IResourceManager resourceManager, String imageData, String imageFolder) throws NoSuchAlgorithmException {
        String imageUrl = null;
        if(imageData != null) {
            String uid = resourceManager.addBase64(imageData);
            if(StringUtils.isNotEmpty(uid)) {
                imageUrl = imageFolder + Resource.RESOURCE_UID_PREFIX + uid;
                final String basePattern = "base64,";
                final String dataPattern = "data:image/";

                int pos = imageData.indexOf(basePattern);
                if (imageData.startsWith(dataPattern)) {
                    imageUrl += '.' + imageData.substring(dataPattern.length(), pos - 1);
                }
            }
        }
        return imageUrl;
    }
}
